==> kubernetes-model-1.0.29-sources.jar: annotations/io/fabric8/openshift/api/model/SubjectAccessReviewResponseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class SubjectAccessReviewResponseFluentImpl<T extends SubjectAccessReviewResponseFluent<T>> extends BaseFluent<T> implements SubjectAccessReviewResponseFluent<T>{

     Boolean allowed;     SubjectAccessReviewResponse.ApiVersion apiVersion;     String kind;     String namespace;     String reason;     Map<String, Object> additionalProperties = new HashMap();

    public Boolean isAllowed(){
    return this.allowed;
    }
    public T withAllowed( Boolean allowed){
    this.allowed=allowed; return (T) this;
    }
    public SubjectAccessReviewResponse.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( SubjectAccessReviewResponse.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public String getNamespace(){
    return this.namespace;
    }
    public T withNamespace( String namespace){
    this.namespace=namespace; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
SubjectAccessReviewResponseFluentImpl that = (SubjectAccessReviewResponseFluentImpl) o;
if (allowed != null ? !allowed.equals(that.allowed) :that.allowed != null) return false;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.31-sources.jar: annotations/io/fabric8/openshift/api/model/SubjectAccessReviewResponseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class SubjectAccessReviewResponseFluentImpl<T extends SubjectAccessReviewResponseFluent<T>> extends BaseFluent<T> implements SubjectAccessReviewResponseFluent<T>{

     Boolean allowed;     SubjectAccessReviewResponse.ApiVersion apiVersion;     String kind;     String namespace;     String reason;     Map<String, Object> additionalProperties = new HashMap();

    public Boolean isAllowed(){
    return this.allowed;
    }
    public T withAllowed( Boolean allowed){
    this.allowed=allowed; return (T) this;
    }
    public SubjectAccessReviewResponse.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( SubjectAccessReviewResponse.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public String getNamespace(){
    return this.namespace;
    }
    public T withNamespace( String namespace){
    this.namespace=namespace; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
SubjectAccessReviewResponseFluentImpl that = (SubjectAccessReviewResponseFluentImpl) o;
if (allowed != null ? !allowed.equals(that.allowed) :that.allowed != null) return false;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
